import { IVpc } from "aws-cdk-lib/aws-ec2";
import { ICluster } from "aws-cdk-lib/aws-ecs";
import { IHostedZone } from "aws-cdk-lib/aws-route53";
import { Construct } from "constructs";
import { EcsTask } from "./EcsTask";
import { StaticHosting } from "./StaticHosting";
import { CloudFrontDistributionConfig, WordpressAdminProps, WordpressDatabaseProps } from "./types";
import { WordpressDockerImage, WordpressDockerImageProps } from "./WordpressDockerImage";
export interface StaticWordpressProps {
    /** The fully qualified site name (e.g., myblog.com or subdomain.myblog.com) */
    readonly fullyQualifiedSiteName: string;
    /**
     * An ID to use throughout this construct to identify resources. Any non-word characters will be replaced with
     * dashes.
     *
     * NOTE: if you intend to change the domain name (via `fullyQualifiedSiteName`), you should set this `siteId` to
     * a static value. Otherwise, the `siteId` will change when you change the site name.
     *
     * @default - the `fullyQualifiedSiteName` will be sanitized and used
     */
    readonly siteId?: string;
    /** The HostedZone to use to create DNS entries for the site */
    readonly hostedZone: IHostedZone;
    /**
     * The VPC assigned to the `ecsCluster`.
     *
     * @default - a new VPC will be created
     */
    readonly vpc?: IVpc;
    /**
     * The ECS cluster for the Wordpress admin site.
     *
     * @default - a new ECS cluster will be created
     */
    readonly ecsCluster?: ICluster;
    readonly wordpressDatabaseProps?: WordpressDatabaseProps;
    readonly wordpressDockerImageProps?: WordpressDockerImageProps;
    readonly wordpressAdminProps: WordpressAdminProps;
    readonly cloudFrontDistributionConfig?: CloudFrontDistributionConfig;
}
export declare class StaticWordpress extends Construct {
    readonly staticHosting: StaticHosting;
    readonly wordpressDockerImage: WordpressDockerImage;
    readonly ecsTask: EcsTask;
    constructor(scope: Construct, id: string, props: StaticWordpressProps);
}
export { EcsTask, EcsTaskProps } from "./EcsTask";
export * from "./generated/BehaviorOverrides";
export * from "./generated/ContainerOverrides";
export * from "./generated/DatabaseOverrides";
export * from "./generated/DistributionOverrides";
export * from "./generated/ServiceOverrides";
export * from "./generated/TaskDefinitionOverrides";
export { StaticHosting, StaticHostingProps } from "./StaticHosting";
export * from "./types";
export { WordpressDockerImage, WordpressDockerImageProps } from "./WordpressDockerImage";
